Learn R Programming

BDAlgo (version 0.1.0)

Abundance: Abundance data sample

Description

The Abundance data are a sample of the entire data set used in Karasiewicz et al.(2022).

Usage

data(Abundance)

Arguments

Format

The Abundance is a matrix covering two stations and three species.

References

Karasiewicz S., and Lefebvre A. (2022). Environmental Impact on Harmful Species Pseudo-nitzschia spp. and Phaeocystis globosa Phenology and Niche. JMSE 10(2), 174. tools:::Rd_expr_doi("10.3390/jmse10020174").